#!/bin/sh

nfsd="/usr/hddapp/sbin/rpc.nfsd"
mountd="/usr/hddapp/sbin/rpc.mountd"
exportfs="/usr/hddapp/sbin/exportfs"
portmap="/usr/hddapp/sbin/portmap"

rm -f /etc/exports
ln -s /usr/hddapp/etc/exports /etc/exports

# Number of servers to be started by default
RPCNFSDCOUNT=4

# Get the initial values for the input sock queues
# at the time of running the script.
RMEM_DEFAULT=`/sbin/sysctl -n net.core.rmem_default`
RMEM_MAX=`/sbin/sysctl -n net.core.rmem_max`
# 256kb recommended minimum size based on SPECsfs NFS benchmarks
NFS_QS=262144

# See how we were called.
case "$1" in
  start)
	$portmap

	# Start daemons.
	# Apply input queue increase for nfs server
 	/sbin/sysctl -w net.core.rmem_default=$NFSD_QS >/dev/null 2>&1
	/sbin/sysctl -w net.core.rmem_max=$NFSD_QS >/dev/null 2>&1
	echo "Starting NFS services"
	$exportfs -r
	echo -n "Starting NFS daemon: "
	$nfsd $RPCNFSDCOUNT
	echo

	[ -n "$MOUNTD_PORT" ] \
	&& RPCMOUNTDOPTS="$RPCMOUNTDOPTS -p $MOUNTD_PORT"

	echo -n "Starting NFS mountd: "
	$mountd $RPCMOUNTDOPTS
	echo
	echo "" > /var/lock/nfs
	# reset input queue for rest of network services
	/sbin/sysctl -w net.core.rmem_default=$RMEM_DEFAULT >/dev/null 2>&1
	/sbin/sysctl -w net.core.rmem_max=$RMEM_MAX >/dev/null 2>&1
	;;
  stop)
	# Stop daemons.
	echo -n "Shutting down NFS mountd: "
	killall -9 rpc.mountd
	echo
	echo -n "Shutting down NFS daemon: "
	killall -9 nfsd
	echo
	# Do it the last so that clients can still access the server
	# when the server is running.
	echo -n "Shutting down NFS services: " 
	$exportfs -au
	rm -f /var/lock/nfs

	killall portmap
	;;
  restart)
	$0 stop
	$0 start
	;;
  reload)
	$exportfs -r
	touch /var/lock/nfs
	;;
  *)
	echo "Usage: nfs {start|stop|restart|reload}"
	exit 1
esac

exit 0
